searchNodes=[{"doc":"Helpers for generating feature test modules. This module needs to be used within your ExUnit.Case module to provide functionalities needed for building feature tests within your regular ExUnit tests. For documentation about defining steps, check out Watermelon.DSL. Example defmodule MyApp.FeatureTest do use ExUnit.Case, async: true use Watermelon.Case feature &quot;&quot;&quot; Feature: Example Scenario: simple test Given empty stack And pushed 1 And pushed 2 When execute sum function Then have 3 on top of stack &quot;&quot;&quot; defgiven match when &quot;empty stack&quot;, do: {:ok, stack: []} defgiven match(val) when &quot;pushed {num}&quot;, context: %{stack: stack} do {:ok, stack: [val | stack]} end defwhen match when &quot;execute sum function&quot;, context: ctx do assert [a, b | rest] = ctx.stack {:ok, stack: [a + b | rest]} end defthen match(result) when &quot;have {num} on top of stack&quot;, context: ctx do assert [^result | _] = ctx.stack end end Which is rough equivalent of: defmodule MyApp.FeatureTest do use ExUnit.Case, async: true test &quot;simple test&quot; do stack = [1, 2] assert [a, b | _] = stack assert 3 == a + b end end Importing steps from different modules In time amount of steps can grow and grow, and a lot of them will repeat between different tests, so for your convenience Watermelon.Case provide a way for importing steps definitions from other modules via setting @step_modules module attribute. For example to split above steps we can use: defmodule MyApp.FeatureTest do use ExUnit.Case, async: true use Watermelon.Case @step_modules [ MyApp.StackSteps ] feature_file &quot;stack.feature&quot; end Setup and teardown Nothing special there, just use old ExUnit.Callbacks.setup/2 or ExUnit.Callbacks.setup_all/2 like in any other of Your test modules.","ref":"Watermelon.Case.html","title":"Watermelon.Case","type":"module"},{"doc":"Define inline feature description. It accepts inline feature description declaration. Example defmodule ExampleTest do use ExUnit.Case use Watermelon.Case feature &quot;&quot;&quot; Feature: Inline feature Scenario: Example Given foo When bar Then baz &quot;&quot;&quot; # Steps definitions end","ref":"Watermelon.Case.html#feature/1","title":"Watermelon.Case.feature/1","type":"macro"},{"doc":"Load file from features directory. Default features directory is set to test/features, however you can change it by setting config :watermelon, features_path: &quot;my_features_dir/&quot; in your configuration file. Example defmodule ExampleTest do use ExUnit.Case use Watermelon.Case feature_file &quot;my_feature.feature&quot; # Steps definitions end","ref":"Watermelon.Case.html#feature_file/1","title":"Watermelon.Case.feature_file/1","type":"macro"},{"doc":"","ref":"Watermelon.Case.html#scenarios/1","title":"Watermelon.Case.scenarios/1","type":"function"},{"doc":"Module with helper functions for defining Gherkin steps. Defining steps There are 3 helper macros that allows you to define steps for your feature specs: defgiven/3 defwhen/3 defthen/3 All with exactly the same syntax: defgiven match(a, b) when &quot;sum of {int} and {int}&quot; do {:ok, sum: a + b} end Syntax for when part is identical with Watermelon.Expression.from/1 so you can provide either Regex or string. Matching groups are then the arguments for match function. Context Step definition can access and modify it&#39;s context which is a way to propagate values between different steps. Return value can be one of: true :ok keyword list map tuple {:ok, map() | keyword()} In case of keyword list or map, the returned values will be merged into current context. When it is :ok or true then the context will be left as is. Context can be made available by using :context option: defwhen match(a) when &quot;I multiply sum by {int}&quot;, context: ctx do {:ok, result: a * ctx.sum} end TODO add support for data table add support for doc strings","ref":"Watermelon.DSL.html","title":"Watermelon.DSL","type":"module"},{"doc":"","ref":"Watermelon.DSL.html#defgiven/3","title":"Watermelon.DSL.defgiven/3","type":"macro"},{"doc":"","ref":"Watermelon.DSL.html#defthen/3","title":"Watermelon.DSL.defthen/3","type":"macro"},{"doc":"","ref":"Watermelon.DSL.html#defwhen/3","title":"Watermelon.DSL.defwhen/3","type":"macro"},{"doc":"Register new step function. Returns function name that must be used in step definition.","ref":"Watermelon.DSL.html#register_step/3","title":"Watermelon.DSL.register_step/3","type":"function"},{"doc":"","ref":"Watermelon.Expression.html","title":"Watermelon.Expression","type":"module"},{"doc":"Creates new expression using provided type. When regular expression is passed then it will assume that this will be exactly the matcher for the given step, it will not use any transformations and will return all matched groups (but not whole match) to the match function. When string is passed it will parse it as a Cucumber expression and will be parsed as Cucumber expression. To match resulting value against your string, see match/2. Default types registered {int} that will match \\d+ regular expression and will return number which is represented by decimal values that were matched {float} that will match \\d*\\.\\d+ and will return float represented by the decimal value that is matched, it also allows floats without digits before dot, so &quot;.1&quot; will be matched and will result with 0.1 {word} that will match any whitespace delimited word {string} that will match any quoted/double-quoted string (escaping of the nested quotes is not supported) {} what will match any string, this can be used only once at the end of the string, otherwise will always cause match failures Examples iex&gt; Watermelon.Expression.from(~r/^foo and (\\d+) bar(:?s)$/) #Watermelon.Expression&lt;~r/^foo and (\\d+) bar(:?s)$/&gt; iex&gt; Watermelon.Expression.from(&quot;foo and {int} bar(s)&quot;) #Watermelon.Expression&lt;foo and {int} bar(s)&gt; Above expressions are will match exactly the same steps, however the second one (one using Cucumber expressions) will automatically convert matched value to integer while the one using regular expression will leave it as a string.","ref":"Watermelon.Expression.html#from/1","title":"Watermelon.Expression.from/1","type":"function"},{"doc":"Run matching against expression.","ref":"Watermelon.Expression.html#match/2","title":"Watermelon.Expression.match/2","type":"function"},{"doc":"Return raw content of the pattern.","ref":"Watermelon.Expression.html#raw/1","title":"Watermelon.Expression.raw/1","type":"function"},{"doc":"Register new type definition for Cucumber expressions. Example iex&gt; Watermelon.Expression.register_type(:bin, ~r/[01]+/, &amp;String.to_integer(&amp;1, 2)) iex&gt; iex&gt; match = Watermelon.Expression.from(&quot;match {bin}&quot;) iex&gt; Watermelon.Expression.match(match, &quot;match 101&quot;) {:ok, [5]}","ref":"Watermelon.Expression.html#register_type/3","title":"Watermelon.Expression.register_type/3","type":"function"},{"doc":"","ref":"Watermelon.Expression.html#t:match_spec/0","title":"Watermelon.Expression.match_spec/0","type":"opaque"},{"doc":"","ref":"Watermelon.Expression.html#t:t/0","title":"Watermelon.Expression.t/0","type":"opaque"}]